# Changelog for drawbot-skia

## [0.2.0] - 2020-09-26

- Added `image(imagePath, position, alpha=1.0)`
- Added `language(language)`
- Fixed signature of `transform(matrix, center=(0, 0))`
- Added `blendMode(blendMode)`
- Added `lineDash(firstValue, *values)`

## [0.1.1] - 2020-09-22

Second first release on PyPI

## [0.1.0] - 2020-09-22

First first release on PyPI
